from enum import Enum
from typing import Set, Dict

REGEXP: str = r"[0-9XYZ]{8}[TRWAGMYFPDXBNJZSQVHLCKE]"
CONTROL_DIGIT: str = "TRWAGMYFPDXBNJZSQVHLCKE"
NOT_ACCEPTED: Set[str] = {"00000000T", "00000001R", "99999999R"}
NIE_FIRST_DIGITS: Dict[str, str] = {"X": "0", "Y": "1", "Z": "2"}


class DNITypes(Enum):
    NIF = "NIF"
    NIE = "NIE"



from spanish_dni.constants import DNITypes, NIE_FIRST_DIGITS


class DNI:
    _number: str
    _control_digit: str
    dni_type: DNITypes

    def __init__(self, number: str, control_digit: str) -> None:
        self._number = number
        self._control_digit = control_digit
        self.dni_type = self.get_dni_type(self._number)

    @classmethod
    def get_dni_type(cls, dni: str) -> DNITypes:
        return DNITypes.NIE if dni[0] in NIE_FIRST_DIGITS.keys() else DNITypes.NIF
